@@ -20,7 +20,7 @@
  * Author: Alexander Larsson <alexl@redhat.com>
  */
 
-#include <config.h>
+#include "config.h"
 #include "gappinfo.h"
 #include "glibintl.h"
 #include <gioerror.h>
@@ -271,7 +271,8 @@ g_app_info_set_as_default_for_extension (GAppInfo    *appinfo,
   if (iface->set_as_default_for_extension)
     return (* iface->set_as_default_for_extension) (appinfo, extension, error);
 
-  g_set_error (error, G_IO_ERROR, G_IO_ERROR_NOT_SUPPORTED, "g_app_info_set_as_default_for_extension not supported yet");
+  g_set_error_literal (error, G_IO_ERROR, G_IO_ERROR_NOT_SUPPORTED,
+                       "g_app_info_set_as_default_for_extension not supported yet");
   return FALSE;
 }
 
@@ -302,9 +303,9 @@ g_app_info_add_supports_type (GAppInfo    *appinfo,
   if (iface->add_supports_type)
     return (* iface->add_supports_type) (appinfo, content_type, error);
 
-  g_set_error (error, G_IO_ERROR, 
-               G_IO_ERROR_NOT_SUPPORTED, 
-               "g_app_info_add_supports_type not supported yet");
+  g_set_error_literal (error, G_IO_ERROR, 
+                       G_IO_ERROR_NOT_SUPPORTED, 
+                       "g_app_info_add_supports_type not supported yet");
 
   return FALSE;
 }
@@ -360,9 +361,9 @@ g_app_info_remove_supports_type (GAppInfo    *appinfo,
   if (iface->remove_supports_type)
     return (* iface->remove_supports_type) (appinfo, content_type, error);
 
-  g_set_error (error, G_IO_ERROR, 
-               G_IO_ERROR_NOT_SUPPORTED, 
-               "g_app_info_remove_supports_type not supported yet");
+  g_set_error_literal (error, G_IO_ERROR, 
+                       G_IO_ERROR_NOT_SUPPORTED, 
+                       "g_app_info_remove_supports_type not supported yet");
 
   return FALSE;
 }
@@ -638,9 +639,9 @@ g_app_launch_context_get_display (GAppLaunchContext *context,
  * Initiates startup notification for the applicaiont and returns the
  * DESKTOP_STARTUP_ID for the launched operation, if supported.
  *
- * Startup notification IDs are defined in the FreeDesktop.Org Startup 
- * Notifications standard, at 
- * <ulink url="http://standards.freedesktop.org/startup-notification-spec/startup-notification-latest.txt"/>.
+ * Startup notification IDs are defined in the <ulink
+ * url="http://standards.freedesktop.org/startup-notification-spec/startup-notification-latest.txt">
+ * FreeDesktop.Org Startup Notifications standard</ulink>.
  *
  * Returns: a startup notification ID for the application, or %NULL if 
  *     not supported.
