@@ -22,12 +22,13 @@
  * Author: Alexander Larsson <alexl@redhat.com>
  */
 
-#include <config.h>
+#include "config.h"
 #include <sys/types.h>
 #include <string.h>
 #include <stdio.h>
 #include "gcontenttypeprivate.h"
 #include "gthemedicon.h"
+#include "gicon.h"
 #include "glibintl.h"
 
 #include "gioalias.h"
@@ -65,14 +66,30 @@ get_registry_classes_key (const char    *subdir,
 		     KEY_QUERY_VALUE, &reg_key) == ERROR_SUCCESS &&
       RegQueryValueExW (reg_key, key_name, 0,
 			&key_type, NULL, &nbytes) == ERROR_SUCCESS &&
-      key_type == REG_SZ)
+      (key_type == REG_SZ || key_type == REG_EXPAND_SZ))
     {
       wchar_t *wc_temp = g_new (wchar_t, (nbytes+1)/2 + 1);
       RegQueryValueExW (reg_key, key_name, 0,
 			&key_type, (LPBYTE) wc_temp, &nbytes);
       wc_temp[nbytes/2] = '\0';
-      value_utf8 = g_utf16_to_utf8 (wc_temp, -1, NULL, NULL, NULL);
+      if (key_type == REG_EXPAND_SZ)
+        {
+          wchar_t dummy[1];
+          int len = ExpandEnvironmentStringsW (wc_temp, dummy, 1);
+          if (len > 0)
+            {
+              wchar_t *wc_temp_expanded = g_new (wchar_t, len);
+              if (ExpandEnvironmentStringsW (wc_temp, wc_temp_expanded, len) == len)
+                value_utf8 = g_utf16_to_utf8 (wc_temp_expanded, -1, NULL, NULL, NULL);
+              g_free (wc_temp_expanded);
+            }
+        }
+      else
+        {
+          value_utf8 = g_utf16_to_utf8 (wc_temp, -1, NULL, NULL, NULL);
+        }
       g_free (wc_temp);
+      
     }
   g_free (wc_key);
   
@@ -179,19 +196,66 @@ g_content_type_get_mime_type (const char *type)
   return g_strdup ("application/octet-stream");
 }
 
+G_LOCK_DEFINE_STATIC (_type_icons);
+static GHashTable *_type_icons = NULL;
+
 GIcon *
 g_content_type_get_icon (const char *type)
 {
+  GIcon *themed_icon;
+  char *name = NULL;
+
   g_return_val_if_fail (type != NULL, NULL);
 
-  /* TODO: How do we represent icons???
-     In the registry they are the default value of
+  /* In the Registry icons are the default value of
      HKEY_CLASSES_ROOT\<progid>\DefaultIcon with typical values like:
      <type>: <value>
      REG_EXPAND_SZ: %SystemRoot%\System32\Wscript.exe,3
      REG_SZ: shimgvw.dll,3
   */
-  return NULL;
+  G_LOCK (_type_icons);
+  if (!_type_icons)
+    _type_icons = g_hash_table_new (g_str_hash, g_str_equal);
+  name = g_hash_table_lookup (_type_icons, type);
+  if (!name && type[0] == '.')
+    {
+      /* double lookup by extension */
+      gchar *key = get_registry_classes_key (type, NULL);
+      if (!key)
+        key = g_strconcat (type+1, "file\\DefaultIcon", NULL);
+      else
+        {
+	  gchar *key2 = g_strconcat (key, "\\DefaultIcon", NULL);
+	  g_free (key);
+	  key = key2;
+	}
+      name = get_registry_classes_key (key, NULL);
+      if (name && strcmp (name, "%1") == 0)
+        {
+	  g_free (name);
+	  name = NULL;
+	}
+      if (name)
+        g_hash_table_insert (_type_icons, g_strdup (type), g_strdup (name));
+      g_free (key);
+    }
+
+  /* icon-name similar to how it was with gtk-2-12 */
+  if (name)
+    {
+      themed_icon = g_themed_icon_new (name);
+    }
+  else
+    {
+      /* if not found an icon fall back to gtk-builtins */
+      name = strcmp (type, "inode/directory") == 0 ? "gtk-directory" : 
+	                   g_content_type_can_be_executable (type) ? "gtk-execute" : "gtk-file";
+      g_hash_table_insert (_type_icons, g_strdup (type), g_strdup (name));
+      themed_icon = g_themed_icon_new_with_default_fallbacks (name);
+    }
+  G_UNLOCK (_type_icons);
+
+  return G_ICON (themed_icon);
 }
 
 gboolean
@@ -203,6 +267,18 @@ g_content_type_can_be_executable (const char *type)
       strcmp (type, ".com") == 0 ||
       strcmp (type, ".bat") == 0)
     return TRUE;
+
+  /* TODO: Also look at PATHEXT, which lists the extensions for
+   * "scripts" in addition to those for true binary executables.
+   *
+   * (PATHEXT=.COM;.EXE;.BAT;.CMD;.VBS;.VBE;.JS;.JSE;.WSF;.WSH for me
+   * right now, for instance). And in a sense, all associated file
+   * types are "executable" on Windows... You can just type foo.jpg as
+   * a command name in cmd.exe, and it will run the application
+   * associated with .jpg. Hard to say what this API actually means
+   * with "executable".
+   */
+
   return FALSE;
 }
 
@@ -659,12 +735,18 @@ GIcon *
 g_content_type_get_icon (const char *type)
 {
   char *mimetype_icon, *generic_mimetype_icon, *q;
-  char *icon_names[3];
+  char *xdg_mimetype_icon, *legacy_mimetype_icon;
+  char *icon_names[4];
+  int n = 0;
   const char *p;
   GIcon *themed_icon;
   
   g_return_val_if_fail (type != NULL, NULL);
   
+  G_LOCK (gio_xdgmime);
+  xdg_mimetype_icon = g_strdup (xdg_mime_get_icon (type));
+  G_UNLOCK (gio_xdgmime);
+
   mimetype_icon = g_strdup (type);
   
   while ((q = strchr (mimetype_icon, '/')) != NULL)
@@ -673,21 +755,27 @@ g_content_type_get_icon (const char *type)
   p = strchr (type, '/');
   if (p == NULL)
     p = type + strlen (type);
+
+  /* Not all icons have migrated to the new icon theme spec, look for old names too */
+  legacy_mimetype_icon = g_strconcat ("gnome-mime-", mimetype_icon, NULL);
   
   generic_mimetype_icon = g_malloc (p - type + strlen ("-x-generic") + 1);
   memcpy (generic_mimetype_icon, type, p - type);
   memcpy (generic_mimetype_icon + (p - type), "-x-generic", strlen ("-x-generic"));
   generic_mimetype_icon[(p - type) + strlen ("-x-generic")] = 0;
   
-  icon_names[0] = mimetype_icon;
-  /* Not all icons have migrated to the new icon theme spec, look for old names too */
-  icon_names[1] = g_strconcat ("gnome-mime-", mimetype_icon, NULL);
-  icon_names[2] = generic_mimetype_icon;
+  if (xdg_mimetype_icon)
+    icon_names[n++] = xdg_mimetype_icon;
+
+  icon_names[n++] = mimetype_icon;
+  icon_names[n++] = legacy_mimetype_icon;
+  icon_names[n++] = generic_mimetype_icon;
   
-  themed_icon = g_themed_icon_new_from_names (icon_names, 3);
+  themed_icon = g_themed_icon_new_from_names (icon_names, n);
   
+  g_free (xdg_mimetype_icon);
   g_free (mimetype_icon);
-  g_free (icon_names[1]);
+  g_free (legacy_mimetype_icon);
   g_free (generic_mimetype_icon);
   
   return themed_icon;
@@ -745,10 +833,16 @@ looks_like_text (const guchar *data, gsize data_size)
 char *
 g_content_type_from_mime_type (const char *mime_type)
 {
+  char *umime;
+
   g_return_val_if_fail (mime_type != NULL, NULL);
 
+  G_LOCK (gio_xdgmime);
   /* mime type and content type are same on unixes */
-  return g_strdup (mime_type);
+  umime = g_strdup (xdg_mime_unalias_mime_type (mime_type));
+  G_UNLOCK (gio_xdgmime);
+
+  return umime;
 }
 
 /**
@@ -845,7 +939,7 @@ g_content_type_guess (const char   *filename,
       
       if (mimetype == NULL)
 	{
-	  /* Conflicts, and sniffed type was no help or not there. guess on the first one */
+	  /* Conflicts, and sniffed type was no help or not there. Guess on the first one */
 	  mimetype = g_strdup (name_mimetypes[0]);
 	  if (result_uncertain)
 	    *result_uncertain = TRUE;
