@@ -22,7 +22,7 @@
  * Author: Alexander Larsson <alexl@redhat.com>
  */
 
-#include <config.h>
+#include "config.h"
 
 #ifdef HAVE_SYS_TIME_H
 #include <sys/time.h>
@@ -712,22 +712,22 @@ set_xattr (char                       *filename,
 
   if (attr_value == NULL)
     {
-      g_set_error (error, G_IO_ERROR, G_IO_ERROR_INVALID_ARGUMENT,
-                   _("Attribute value must be non-NULL"));
+      g_set_error_literal (error, G_IO_ERROR, G_IO_ERROR_INVALID_ARGUMENT,
+                           _("Attribute value must be non-NULL"));
       return FALSE;
     }
 
   if (attr_value->type != G_FILE_ATTRIBUTE_TYPE_STRING)
     {
-      g_set_error (error, G_IO_ERROR, G_IO_ERROR_INVALID_ARGUMENT,
-                   _("Invalid attribute type (string expected)"));
+      g_set_error_literal (error, G_IO_ERROR, G_IO_ERROR_INVALID_ARGUMENT,
+                           _("Invalid attribute type (string expected)"));
       return FALSE;
     }
 
   if (!name_is_valid (escaped_attribute))
     {
-      g_set_error (error, G_IO_ERROR, G_IO_ERROR_INVALID_ARGUMENT,
-		   _("Invalid extended attribute name"));
+      g_set_error_literal (error, G_IO_ERROR, G_IO_ERROR_INVALID_ARGUMENT,
+                           _("Invalid extended attribute name"));
       return FALSE;
     }
 
@@ -1465,7 +1465,6 @@ _g_local_file_info_get (const char             *basename,
   is_symlink = FALSE;
 #endif
   symlink_broken = FALSE;
-  
 #ifdef S_ISLNK
   if (is_symlink)
     {
@@ -1565,18 +1564,17 @@ _g_local_file_info_get (const char             *basename,
 	    {
 	      GIcon *icon;
 
-              icon = g_content_type_get_icon (content_type);
-              if (icon != NULL)
+              if (strcmp (path, g_get_home_dir ()) == 0)
+                icon = g_themed_icon_new ("user-home");
+              else if (strcmp (path, g_get_user_special_dir (G_USER_DIRECTORY_DESKTOP)) == 0) 
+                icon = g_themed_icon_new ("user-desktop");
+              else 
                 {
+                  icon = g_content_type_get_icon (content_type);
                   if (G_IS_THEMED_ICON (icon))
                     {
-                      const char *preferred_icon = NULL;
                       const char *type_icon = NULL;
 
-                      if (strcmp (path, g_get_home_dir ()) == 0)
-                        preferred_icon = "user-home";
-                      else if (strcmp (path, g_get_user_special_dir (G_USER_DIRECTORY_DESKTOP)) == 0) 
-                        preferred_icon = "user-desktop";
                       if (S_ISDIR (statbuf.st_mode)) 
                         type_icon = "folder";
                       else if (statbuf.st_mode & S_IXUSR)
@@ -1584,12 +1582,12 @@ _g_local_file_info_get (const char             *basename,
                       else
                         type_icon = "text-x-generic";
 
-                      if (preferred_icon)
-                        g_themed_icon_prepend_name (G_THEMED_ICON (icon), preferred_icon);
-                      if (type_icon) 
-                        g_themed_icon_append_name (G_THEMED_ICON (icon), type_icon);
+                      g_themed_icon_append_name (G_THEMED_ICON (icon), type_icon);
                     }
+                }
 
+              if (icon != NULL)
+                {
                   g_file_info_set_icon (info, icon);
                   g_object_unref (icon);
                 }
@@ -1739,8 +1737,8 @@ get_uint32 (const GFileAttributeValue  *value,
 {
   if (value->type != G_FILE_ATTRIBUTE_TYPE_UINT32)
     {
-      g_set_error (error, G_IO_ERROR, G_IO_ERROR_INVALID_ARGUMENT,
-		   _("Invalid attribute type (uint32 expected)"));
+      g_set_error_literal (error, G_IO_ERROR, G_IO_ERROR_INVALID_ARGUMENT,
+                           _("Invalid attribute type (uint32 expected)"));
       return FALSE;
     }
 
@@ -1757,8 +1755,8 @@ get_uint64 (const GFileAttributeValue  *value,
 {
   if (value->type != G_FILE_ATTRIBUTE_TYPE_UINT64)
     {
-      g_set_error (error, G_IO_ERROR, G_IO_ERROR_INVALID_ARGUMENT,
-		   _("Invalid attribute type (uint64 expected)"));
+      g_set_error_literal (error, G_IO_ERROR, G_IO_ERROR_INVALID_ARGUMENT,
+                           _("Invalid attribute type (uint64 expected)"));
       return FALSE;
     }
 
@@ -1776,8 +1774,8 @@ get_byte_string (const GFileAttributeValue  *value,
 {
   if (value->type != G_FILE_ATTRIBUTE_TYPE_BYTE_STRING)
     {
-      g_set_error (error, G_IO_ERROR, G_IO_ERROR_INVALID_ARGUMENT,
-		   _("Invalid attribute type (byte string expected)"));
+      g_set_error_literal (error, G_IO_ERROR, G_IO_ERROR_INVALID_ARGUMENT,
+                           _("Invalid attribute type (byte string expected)"));
       return FALSE;
     }
 
@@ -1876,8 +1874,8 @@ set_symlink (char                       *filename,
   
   if (val == NULL)
     {
-      g_set_error (error, G_IO_ERROR, G_IO_ERROR_INVALID_ARGUMENT,
-		   _("symlink must be non-NULL"));
+      g_set_error_literal (error, G_IO_ERROR, G_IO_ERROR_INVALID_ARGUMENT,
+                           _("symlink must be non-NULL"));
       return FALSE;
     }
   
@@ -1894,9 +1892,9 @@ set_symlink (char                       *filename,
   
   if (!S_ISLNK (statbuf.st_mode))
     {
-      g_set_error (error, G_IO_ERROR,
-		   G_IO_ERROR_NOT_SYMBOLIC_LINK,
-		   _("Error setting symlink: file is not a symlink"));
+      g_set_error_literal (error, G_IO_ERROR,
+                           G_IO_ERROR_NOT_SYMBOLIC_LINK,
+                           _("Error setting symlink: file is not a symlink"));
       return FALSE;
     }
   
