@@ -28,8 +28,7 @@
 #ifndef __G_MOUNT_H__
 #define __G_MOUNT_H__
 
-#include <glib-object.h>
-#include <gio/gfile.h>
+#include <gio/giotypes.h>
 
 G_BEGIN_DECLS
 
@@ -38,21 +37,6 @@ G_BEGIN_DECLS
 #define G_IS_MOUNT(obj)         (G_TYPE_CHECK_INSTANCE_TYPE ((obj), G_TYPE_MOUNT))
 #define G_MOUNT_GET_IFACE(obj)  (G_TYPE_INSTANCE_GET_INTERFACE ((obj), G_TYPE_MOUNT, GMountIface))
 
-/* GMount typedef is in gfile.h due to include order issues */
-/**
- * GVolume:
- * 
- * Opaque mountable volume object.
- **/
-typedef struct _GVolume GVolume; /* Dummy typedef */
-
-/**
- * GDrive:
- * 
- * Opaque drive object.
- **/
-typedef struct _GDrive          GDrive; /* Dummy typedef */
-
 typedef struct _GMountIface    GMountIface;
 
 /**
@@ -113,6 +97,7 @@ struct _GMountIface
                                               GAsyncResult    *result,
                                               GError         **error);
   void               (*remount)              (GMount         *mount,
+					      GMountMountFlags     flags,
 					      GMountOperation     *mount_operation,
                                               GCancellable    *cancellable,
                                               GAsyncReadyCallback callback,
@@ -149,6 +134,7 @@ gboolean           g_mount_eject_finish         (GMount              *mount,
                                                  GAsyncResult        *result,
                                                  GError             **error);
 void               g_mount_remount              (GMount              *mount,
+						 GMountMountFlags     flags,
 						 GMountOperation     *mount_operation,
                                                  GCancellable        *cancellable,
                                                  GAsyncReadyCallback  callback,
