@@ -22,7 +22,7 @@
  * Author: Alexander Larsson <alexl@redhat.com>
  */
 
-#include <config.h>
+#include "config.h"
 
 #include <sys/types.h>
 #include <sys/stat.h>
@@ -44,6 +44,7 @@
 #include <errno.h>
 #include <string.h>
 #include <signal.h>
+#include <gstdio.h>
 
 #include "gunixmounts.h"
 #include "gfile.h"
@@ -1130,9 +1131,8 @@ g_unix_mount_monitor_finalize (GObject *object)
     }
 
   the_mount_monitor = NULL;
-  
-  if (G_OBJECT_CLASS (g_unix_mount_monitor_parent_class)->finalize)
-    (*G_OBJECT_CLASS (g_unix_mount_monitor_parent_class)->finalize) (object);
+
+  G_OBJECT_CLASS (g_unix_mount_monitor_parent_class)->finalize (object);
 }
 
 
@@ -1230,10 +1230,37 @@ g_unix_mount_monitor_init (GUnixMountMonitor *monitor)
     }
 }
 
+/**
+ * g_unix_mount_monitor_set_rate_limit:
+ * @mount_monitor: a #GUnixMountMonitor
+ * @limit_msec: a integer with the limit in milliseconds to
+ *     poll for changes.
+ *
+ * Sets the rate limit to which the @mount_monitor will report
+ * consecutive change events to the mount and mount point entry files.
+ *
+ * Since: 2.18
+ **/
+void
+g_unix_mount_monitor_set_rate_limit (GUnixMountMonitor *mount_monitor,
+                                     int                limit_msec)
+{
+  g_return_if_fail (G_IS_UNIX_MOUNT_MONITOR (mount_monitor));
+
+  if (mount_monitor->fstab_monitor != NULL)
+    g_file_monitor_set_rate_limit (mount_monitor->fstab_monitor, limit_msec);
+
+  if (mount_monitor->mtab_monitor != NULL)
+    g_file_monitor_set_rate_limit (mount_monitor->mtab_monitor, limit_msec);
+}
+
 /**
  * g_unix_mount_monitor_new:
  * 
- * Gets a new #GUnixMountMonitor.
+ * Gets a new #GUnixMountMonitor. The default rate limit for which the
+ * monitor will report consecutive changes for the mount and mount
+ * point entry files is the default for a #GFileMonitor. Use
+ * g_unix_mount_monitor_set_rate_limit() to change this.
  * 
  * Returns: a #GUnixMountMonitor. 
  **/
@@ -1568,7 +1595,8 @@ guess_mount_type (const char *mount_path,
       (strcmp (filesystem_type, "iso9660") == 0) ||
       (strcmp (filesystem_type, "cd9660") == 0))
     type = G_UNIX_MOUNT_TYPE_CDROM;
-  else if (strcmp (filesystem_type, "nfs") == 0)
+  else if ((strcmp (filesystem_type, "nfs") == 0) ||
+           (strcmp (filesystem_type, "nfs4") == 0))
     type = G_UNIX_MOUNT_TYPE_NFS;
   else if (g_str_has_prefix (device_path, "/vol/dev/diskette/") ||
 	   g_str_has_prefix (device_path, "/dev/fd") ||
@@ -1598,27 +1626,10 @@ guess_mount_type (const char *mount_path,
     {
       basename = g_path_get_basename (mount_path);
       
-      if (g_str_has_prefix (basename, "cdrom") ||
+      if (g_str_has_prefix (basename, "cdr") ||
 	  g_str_has_prefix (basename, "cdwriter") ||
 	  g_str_has_prefix (basename, "burn") ||
-	  g_str_has_prefix (basename, "cdr") ||
-	  g_str_has_prefix (basename, "cdrw") ||
-	  g_str_has_prefix (basename, "dvdrom") ||
-	  g_str_has_prefix (basename, "dvdram") ||
-	  g_str_has_prefix (basename, "dvdr") ||
-	  g_str_has_prefix (basename, "dvdrw") ||
-	  g_str_has_prefix (basename, "cdrom_dvdrom") ||
-	  g_str_has_prefix (basename, "cdrom_dvdram") ||
-	  g_str_has_prefix (basename, "cdrom_dvdr") ||
-	  g_str_has_prefix (basename, "cdrom_dvdrw") ||
-	  g_str_has_prefix (basename, "cdr_dvdrom") ||
-	  g_str_has_prefix (basename, "cdr_dvdram") ||
-	  g_str_has_prefix (basename, "cdr_dvdr") ||
-	  g_str_has_prefix (basename, "cdr_dvdrw") ||
-	  g_str_has_prefix (basename, "cdrw_dvdrom") ||
-	  g_str_has_prefix (basename, "cdrw_dvdram") ||
-	  g_str_has_prefix (basename, "cdrw_dvdr") ||
-	  g_str_has_prefix (basename, "cdrw_dvdrw"))
+	  g_str_has_prefix (basename, "dvdr"))
 	type = G_UNIX_MOUNT_TYPE_CDROM;
       else if (g_str_has_prefix (basename, "floppy"))
 	type = G_UNIX_MOUNT_TYPE_FLOPPY;
@@ -1865,7 +1876,6 @@ g_unix_mount_guess_can_eject (GUnixMountEntry *mount_entry)
 gboolean
 g_unix_mount_guess_should_display (GUnixMountEntry *mount_entry)
 {
-  GUnixMountType guessed_type;
   const char *mount_path;
 
   /* Never display internal mountpoints */
@@ -1877,13 +1887,26 @@ g_unix_mount_guess_should_display (GUnixMountEntry *mount_entry)
   mount_path = mount_entry->mount_path;
   if (mount_path != NULL)
     {
-      if (strstr (mount_path, "/.gvfs") != NULL)
+      if (g_str_has_prefix (mount_path, "/media/")) {
+        char *path;
+        /* Avoid displaying mounts that are not accessible to the user.
+         *
+         * See http://bugzilla.gnome.org/show_bug.cgi?id=526320 for why we
+         * want to avoid g_access() for every mount point.
+         */
+        path = g_path_get_dirname (mount_path);
+        if (g_str_has_prefix (path, "/media/"))
+          {
+            if (g_access (path, R_OK|X_OK) != 0) {
+              g_free (path);
+              return FALSE;
+            }
+          }
+        g_free (path);
         return TRUE;
+      }
       
-      if (g_str_has_prefix (mount_path, "/media/"))
-        return TRUE;
-      
-      if (g_str_has_prefix (mount_path, g_get_home_dir ()))
+      if (g_str_has_prefix (mount_path, g_get_home_dir ()) && mount_path[strlen (g_get_home_dir())] == G_DIR_SEPARATOR)
         return TRUE;
     }
   
