@@ -1,3 +1,5 @@
+/* -*- mode: C; c-file-style: "gnu"; indent-tabs-mode: nil; -*- */
+
 /* GIO - GLib Input, Output and Streaming Library
  * 
  * Copyright (C) 2006-2007 Red Hat, Inc.
@@ -21,8 +23,11 @@
  *         David Zeuthen <davidz@redhat.com>
  */
 
-#include <config.h>
+#include "config.h"
 #include "gvolumemonitor.h"
+#include "gvolume.h"
+#include "gmount.h"
+#include "gdrive.h"
 #include "glibintl.h"
 
 #include "gioalias.h"
@@ -30,7 +35,7 @@
 /**
  * SECTION:gvolumemonitor
  * @short_description: Volume Monitor
- * @include: gio.h
+ * @include: gio/gio.h
  * @see_also: #GFileMonitor
  * 
  * #GVolumeMonitor is for listing the user interesting devices and volumes
@@ -64,8 +69,7 @@ g_volume_monitor_finalize (GObject *object)
 
   monitor = G_VOLUME_MONITOR (object);
 
-  if (G_OBJECT_CLASS (g_volume_monitor_parent_class)->finalize)
-    (*G_OBJECT_CLASS (g_volume_monitor_parent_class)->finalize) (object);
+  G_OBJECT_CLASS (g_volume_monitor_parent_class)->finalize (object);
 }
 
 static void
@@ -238,11 +242,11 @@ g_volume_monitor_init (GVolumeMonitor *monitor)
  * @volume_monitor: a #GVolumeMonitor.
  * 
  * Gets a list of drives connected to the system.
- *
- * The returned list should be freed with g_list_free(), but
- * its elements need not be freed.
  * 
- * Returns: a #GList of connected #GDrives - free with g_list_free(). 
+ * The returned list should be freed with g_list_free(), after
+ * its elements have been unreffed with g_object_unref().
+ *
+ * Returns: a #GList of connected #GDrive<!-- -->s
  **/
 GList *
 g_volume_monitor_get_connected_drives (GVolumeMonitor *volume_monitor)
@@ -261,11 +265,11 @@ g_volume_monitor_get_connected_drives (GVolumeMonitor *volume_monitor)
  * @volume_monitor: a #GVolumeMonitor.
  * 
  * Gets a list of the volumes on the system.
- *
- * The returned list should be freed with g_list_free(), but
- * its elements need not be freed.
  * 
- * Returns: a #GList of #GVolume - free with g_list_free().
+ * The returned list should be freed with g_list_free(), after
+ * its elements have been unreffed with g_object_unref().
+ *
+ * Returns: a #GList of #GVolume<!-- -->s.
  **/
 GList *
 g_volume_monitor_get_volumes (GVolumeMonitor *volume_monitor)
@@ -285,10 +289,10 @@ g_volume_monitor_get_volumes (GVolumeMonitor *volume_monitor)
  * 
  * Gets a list of the mounts on the system.
  *
- * The returned list should be freed with g_list_free(), but
- * its elements need not be freed.
+ * The returned list should be freed with g_list_free(), after
+ * its elements have been unreffed with g_object_unref().
  * 
- * Returns: a #GList of #GMount - free with g_list_free().
+ * Returns: a #GList of #GMount<!-- -->s
  **/
 GList *
 g_volume_monitor_get_mounts (GVolumeMonitor *volume_monitor)
